@@ -1,4 +1,4 @@
-#ident "$Header: /cvs/glite/org.glite.lb.state-machine/src/process_event.c,v 1.37 2012/08/01 13:41:07 zsustr Exp $"
+#ident "$Header$"
 /*
 Copyright (c) Members of the EGEE Collaboration. 2004-2010.
 See http://www.eu-egee.org/partners for details on the copyright holders.
@@ -1035,7 +1035,7 @@ static int processEvent_glite(intJobStat *js, edg_wll_Event *e, int ev_seq, int
 					case EDG_WLL_CREAMSTORE_CMDSTART:
 						if (e->CREAMStore.result == EDG_WLL_CREAMSTORE_OK) {
 							js->pub.state = EDG_WLL_JOB_WAITING;
-							js->pub.cream_state = EDG_WLL_STAT_PENDING;
+							js->pub.cream_state = EDG_WLL_STAT_CREAM_PENDING;
 						}
 						break;
 					 case EDG_WLL_CREAMSTORE_CMDSUSPEND:
@@ -1064,7 +1064,7 @@ static int processEvent_glite(intJobStat *js, edg_wll_Event *e, int ev_seq, int
 				if (USABLE(res, strict)) {
                                         // BLAH -> LRMS
 					js->pub.state = EDG_WLL_JOB_SCHEDULED;
-					js->pub.cream_state = EDG_WLL_STAT_IDLE;
+					js->pub.cream_state = EDG_WLL_STAT_CREAM_IDLE;
 					rep_cond(js->pub.cream_reason, e->CREAMCall.reason);
 					rep_cond(js->pub.reason, e->CREAMCall.reason);
 				}
@@ -1084,7 +1084,7 @@ static int processEvent_glite(intJobStat *js, edg_wll_Event *e, int ev_seq, int
 			if (USABLE(res, strict)) {
                                 if (e->CREAMCancel.status_code == EDG_WLL_CANCEL_DONE) {
                                         js->pub.state = EDG_WLL_JOB_CANCELLED;
-                                        js->pub.cream_state = EDG_WLL_STAT_ABORTED;
+                                        js->pub.cream_state = EDG_WLL_STAT_CREAM_ABORTED;
                                 }
 				rep(js->pub.cream_reason, e->CREAMCancel.reason);
                                 rep(js->pub.reason, e->CREAMCancel.reason);
@@ -1093,7 +1093,7 @@ static int processEvent_glite(intJobStat *js, edg_wll_Event *e, int ev_seq, int
 		case EDG_WLL_EVENT_CREAMABORT:
                         if (USABLE(res, strict)) {
                                 js->pub.state = EDG_WLL_JOB_ABORTED;
-                                js->pub.cream_state = EDG_WLL_STAT_ABORTED;
+                                js->pub.cream_state = EDG_WLL_STAT_CREAM_ABORTED;
 				rep(js->pub.cream_reason, e->CREAMAbort.reason);
                                 rep(js->pub.reason, e->CREAMAbort.reason);
                         }
@@ -1103,32 +1103,34 @@ static int processEvent_glite(intJobStat *js, edg_wll_Event *e, int ev_seq, int
                         {
                                 switch (js->pub.cream_state = edg_wll_StringToCreamStat(e->CREAMStatus.new_state))
                                 {
-                                        case EDG_WLL_STAT_REGISTERED:
+                                        case EDG_WLL_STAT_CREAM_REGISTERED:
                                         case EDG_WLL_NUMBER_OF_CREAM_STATES:
                                                 break;
 
-                                        case EDG_WLL_STAT_PENDING: js->pub.state = EDG_WLL_JOB_WAITING; break;
-                                        case EDG_WLL_STAT_IDLE: js->pub.state = EDG_WLL_JOB_SCHEDULED; break;
-                                        case EDG_WLL_STAT_RUNNING:
+                                        case EDG_WLL_STAT_CREAM_PENDING: js->pub.state = EDG_WLL_JOB_WAITING; break;
+                                        case EDG_WLL_STAT_CREAM_IDLE: js->pub.state = EDG_WLL_JOB_SCHEDULED; break;
+                                        case EDG_WLL_STAT_CREAM_RUNNING:
                                                 js->pub.state = EDG_WLL_JOB_RUNNING;
                                                 js->pub.jw_status = EDG_WLL_STAT_WRAPPER_RUNNING;
                                                 break;
-                                        case EDG_WLL_STAT_REALLY_RUNNING:
+                                        case EDG_WLL_STAT_CREAM_REALLY_RUNNING:
                                                 js->pub.state = EDG_WLL_JOB_RUNNING;
                                                 js->pub.jw_status = EDG_WLL_STAT_PAYLOAD_RUNNING;
                                                 break;
-                                        case EDG_WLL_STAT_HELD: /* TODO */ break;
-                                        case EDG_WLL_STAT_DONE_OK:
+                                        case EDG_WLL_STAT_CREAM_HELD: /* TODO */ break;
+                                        case EDG_WLL_STAT_CREAM_DONE_OK:
                                                 js->pub.state = EDG_WLL_JOB_DONE;
                                                 js->pub.done_code = EDG_WLL_STAT_OK;
                                                 js->pub.cream_done_code = EDG_WLL_STAT_OK;
                                                 break;
-                                        case EDG_WLL_STAT_DONE_FAILED:
+                                        case EDG_WLL_STAT_CREAM_DONE_FAILED:
                                                 js->pub.state = EDG_WLL_JOB_DONE;
                                                 js->pub.done_code = EDG_WLL_STAT_FAILED;
                                                 js->pub.cream_done_code = EDG_WLL_STAT_FAILED;
                                                 break;
-                                        case EDG_WLL_STAT_ABORTED: js->pub.state = EDG_WLL_JOB_ABORTED; break;
+                                        case EDG_WLL_STAT_CREAM_ABORTED: js->pub.state = EDG_WLL_JOB_ABORTED; break;
+					case EDG_WLL_STAT_CREAM_CANCELLED: js->pub.state = EDG_WLL_JOB_CANCELLED; break;
+					case EDG_WLL_STAT_CREAM_PURGED: js->pub.state = EDG_WLL_JOB_CLEARED; break;
                                 }
                         }
                         break;
